@@ -220,8 +220,8 @@ class AssetSerializer(NeedsReviewMixin, HistorySerializerMixin):
                 task = add_to_dns.s(old_asset) | asset_update.s({'provisioning': False, 'log': 'Reconfigured networking'}) | reconfigure_network_port.s() | event_emit.s('reprovisioned')
                 task.apply_async((asset,))
             # Shortcut for managing VM disk changes online
-            elif (asset['state'] == 'in-use' and asset['asset_type'] == 'vm' and diff.get('provision', {}).keys() == ['storage'] and
-                  all(map(lambda x: x.keys() == ['size'], diff['provision']['storage'].values()))):
+            elif (asset['state'] == 'in-use' and asset['asset_type'] == 'vm' and list(diff.get('provision', {}).keys()) == ['storage'] and
+                  all([list(x.keys()) == ['size'] for x in diff['provision']['storage'].values()])):
                 from socrates_api.tasks import provision_vm, asset_update, event_emit
                 task = provision_vm.s() | asset_update.s({'provisioning': False, 'log': 'Extended disks'}) | event_emit.s('reprovisioned')
                 task.apply_async((asset,))
@@ -341,6 +341,10 @@ class AssetSerializer(NeedsReviewMixin, HistorySerializerMixin):
             new_asset = dict_merge(self.instance, data)
         else:
             new_asset = data
+        if self.instance is not None:
+            diff = dict_differences(new_asset, self.instance)
+        else:
+            diff = new_asset
         username = self.get_username()
         if self.instance is not None and username is not None:
             if self.instance.get('maintenance', False) and data.get('provisioning', False):
@@ -529,8 +533,8 @@ class AssetSerializer(NeedsReviewMixin, HistorySerializerMixin):
                         # This ensures the same disk can only be used once
                         pdisks[controller_id].remove(pdisk['id'])
         else:
-            if 'provision' in data and new_asset['state'] == "in-use" and self.instance is not None and (new_asset['asset_type'] != "vm" or username is not None) and not self.instance.get('provisioning', False) and not new_asset.get('provisioning', False) and not new_asset.get('decommissioning', False):
-                raise serializers.ValidationError("Cannot update 'provision' without provisioning set")
+            if 'provision' in diff and new_asset['state'] == "in-use" and self.instance is not None and (new_asset['asset_type'] != "vm" or username is not None) and not self.instance.get('provisioning', False) and not new_asset.get('provisioning', False) and not new_asset.get('decommissioning', False):
+                raise serializers.ValidationError("cannot update 'provision' without provisioning set")
         return data
 
     def create_link(self, instance):
